/*
 * IRwebremote: send remote signals via the web
 * An IR LED must be connected to Arduino PWM pin 3.
 * Codes are received over the serial port and sent on pin 3.
 * Syntax:
 * N12345678  - send 32-bit NEC code
 * S00000123  - send 12-bit Sony code
 * r00000123  - send 12-bit RC5 code
 * R00012345  - send 20-bit RC6 code
 * Copyright 2009 Ken Shirriff
 * http://arcfn.com
 */

#include <IRremote.h>

IRsend irsend;

#define NEC 'N'
#define SONY 'S'
#define RC5 'r'
#define RC6 'R'

void setup()
{
  Serial.begin(9600);
}

unsigned long rctoggle = 0;

void processSerialCode() {
  if (Serial.available() < 9) return;
  char type = Serial.read();
  if (type != NEC && type != SONY && type != RC5 && type != RC6) {
    Serial.print("Unexpected type: ");
    Serial.println(type);
    return;
  }
  // Read 8 hex characters
  unsigned long code = 0;
  for (int i = 0; i < 8; i++) {
    char ch = Serial.read();
    if (ch >= '0' && ch <= '9') {
      code = code * 16 + ch - '0';
    } 
    else if (ch >= 'a' && ch <= 'f') {
      code = code * 16 + ch - 'a' + 10;
    } 
    else if (ch >= 'A' & ch <= 'F') {
      code = code * 16 + ch - 'A' + 10;
    } 
    else {
      Serial.print("Unexpected hex char: ");
      Serial.println(ch);
      return;
    }
  }
  if (type == NEC) {
    irsend.sendNEC(code, 32);
  } 
  else if (type == SONY) {
    // Send Sony code 3 times
    irsend.sendSony(code, 12);
    delay(50);
    irsend.sendSony(code, 12);
    delay(50);
    irsend.sendSony(code, 12);
  } 
  else if (type == RC5) {
    // Filp the RC5 toggle bit
    code = code ^ (rctoggle << 11);
    rctoggle = 1 - rctoggle;
    irsend.sendRC5(code, 12);
  } 
  else if (type == RC6) {
    // Flip the RC6 toggle bit
    code = code ^ (rctoggle << 16);
    rctoggle = 1 - rctoggle;
    irsend.sendRC6(code, 20);
  }
  Serial.print("Sent code: ");
  Serial.println(code, HEX);
}

void loop() {
  processSerialCode();
}


